@@ -10,7 +10,7 @@ import numpy as np
 # from scipy.ndimage.filters import gaussian_filter
 # from scipy.ndimage.filters import median_filter
 import xarray as xr
-from pivpy import graphics
+# from pivpy import graphics
 from scipy.ndimage import gaussian_filter as gf
 
 """ learn from this example
@@ -160,55 +160,31 @@ class PIVAccessor(object):
 
         """
 
-        # ux, uy = np.gradient(self._obj['u'], self._obj['x'],
-        #                    self._obj['y'], axis=(0, 1))
-        # vx, vy = np.gradient(self._obj['v'], self._obj['x'],
-        #                    self._obj['y'], axis=(0, 1))
-        # self._obj['w'] = xr.DataArray(vy - ux, dims=['x', 'y'])
-        # _w = xr.DataArray(vy - ux, dims=['x', 'y', 't'])
-        # if 't' in self._obj.coords:
         self._obj["w"] = (
-            self._obj.differentiate("x")["v"]
-            - self._obj.differentiate("y")["u"]
+            self._obj["v"].differentiate("x")
+            - self._obj["u"].differentiate("y")
         )
-        # else:
-        #     self._obj["w"] = (("x", "y"), vx - uy)
-        # self._obj = self._obj.assign(w=_w)
-        # self._obj.assign(w=vy-ux)
 
-        if len(self._obj.attrs["units"]) < 5:
-            # vel_units = self._obj.attrs['units'][-1]
-            self._obj.attrs["units"].append("1/dt")
-            self._obj.attrs['variables'].append('vorticity')
-        else:
-            # vel_units = self._obj.attrs['units'][-2]
-            self._obj.attrs["units"][-1] = "1/dt"
-            self._obj.attrs['variables'][-1] = 'vorticity'
+        self._obj["w"].attrs["units"] = "1/dt"
+        self._obj["w"].attrs["standard_name"] = "vorticity"
 
         return self._obj
 
     def strain(self):
-        """ calculates shear of the data array (single frame)
+        """ calculates strain rate, du/dx^2 + dv/dy^2 + 1/2 (du/dy+dv/dx)^2
         Input:
             xarray with the variables u,v and dimensions x,y
         Output:
             xarray with the estimated shear as a scalar field data['w']
         """
-        ux = self._obj.differentiate("x")["u"]
-        uy = self._obj.differentiate("y")["u"]
-        vx = self._obj.differentiate("x")["v"]
-        vy = self._obj.differentiate("y")["v"]
+        ux = self._obj["u"].differentiate("x")
+        uy = self._obj["u"].differentiate("y")
+        vx = self._obj["v"].differentiate("x")
+        vy = self._obj["v"].differentiate("y")
 
         self._obj["w"] = ux ** 2 + vy ** 2 + 0.5 * (uy + vx) ** 2
-
-        if len(self._obj.attrs["units"]) < 5:
-            # vel_units = self._obj.attrs['units'][-1]
-            self._obj.attrs["units"].append("1/dt")
-            self._obj.attrs['variables'].append('strain')
-        else:
-            # vel_units = self._obj.attrs['units'][-2]
-            self._obj.attrs["units"][-1] = "1/dt"
-            self._obj.attrs['variables'][1] = 'strain'
+        self._obj["w"].attrs["units"] = "1/dt"
+        self._obj["w"].attrs["standard_name"] = "strain"
 
         return self._obj
 
@@ -231,14 +207,9 @@ class PIVAccessor(object):
         else:
             self._obj["w"] = (("x", "y"), vy + ux)
 
-        if len(self._obj.attrs["units"]) == 4:
-            # vel_units = self._obj.attrs['units'][-1]
-            self._obj.attrs["units"].append("1/dt")
-            self._obj.attrs['variables'].append('divergence')
-        else:
-            # vel_units = self._obj.attrs['units'][-2]
-            self._obj.attrs["units"][-1] = "1/dt"
-            self._obj.attrs['variables'][-1] = 'divergence'
+
+        self._obj["w"].attrs["units"] = "1/dt"
+        self._obj["w"].attrs["standard_name"] = "divergence"
 
         return self._obj
 
@@ -253,10 +224,10 @@ class PIVAccessor(object):
             xarray with the estimated acceleration as a scalar field data['w']
 
         """
-        ux = self._obj.differentiate("x")["u"]
-        uy = self._obj.differentiate("y")["u"]
-        vx = self._obj.differentiate("x")["v"]
-        vy = self._obj.differentiate("y")["v"]
+        ux = self._obj["u"].differentiate("x")
+        uy = self._obj["u"].differentiate("y")
+        vx = self._obj["v"].differentiate("x")
+        vy = self._obj["v"].differentiate("y")
 
         ax = self._obj["u"] * ux + self._obj["v"] * uy
         ay = self._obj["u"] * vx + self._obj["v"] * vy
@@ -265,29 +236,16 @@ class PIVAccessor(object):
             np.sqrt(ax ** 2 + ay ** 2), dims=["x", "y", "t"]
         )
 
-        if len(self._obj.attrs["units"]) == 4:
-            vel_units = self._obj.attrs["units"][-1]
-            self._obj.attrs["units"].append(f"{vel_units}^2")
-            self._obj.attrs['variables'].append('acceleration')
-        else:
-            vel_units = self._obj.attrs["units"][-2]
-            self._obj.attrs["units"][-1] = f"{vel_units}^2"
-            self._obj.attrs['variables'][-1] = 'acceleration'
+        self._obj["w"].attrs["units"] = "1/dt"
+        self._obj["w"].attrs["standard_name"] = "acceleration"
 
         return self._obj
 
-    def ke(self):
+    def kinetic_energy(self):
         """ estimates turbulent kinetic energy """
         self._obj["w"] = self._obj["u"] ** 2 + self._obj["v"] ** 2
-
-        if len(self._obj.attrs["units"]) == 4:
-            vel_units = self._obj.attrs["units"][-1]
-            self._obj.attrs["units"].append(f"({vel_units})^2")
-            self._obj.attrs['variables'].append('ke')
-        else:
-            vel_units = self._obj.attrs["units"][-2]
-            self._obj.attrs["units"][-1] = f"({vel_units})^2"
-            self._obj.attrs['variables'][-1] = 'ke'
+        self._obj["w"].attrs["units"] = "(m/s)^2"
+        self._obj["w"].attrs["standard_name"] = "kinetic_energy"
         return self._obj
 
     def tke(self):
@@ -295,20 +253,16 @@ class PIVAccessor(object):
         if len(self._obj.t) < 2:
             raise ValueError(
                 "TKE is not defined for a single vector field, \
-                              use .piv.ke()"
+                              use .piv.kinetic_energy()"
             )
+        
+        new_obj = self._obj.copy()
+        new_obj -= new_obj.mean(dim="t")
+        new_obj["w"] = new_obj["u"] ** 2 + new_obj["v"] ** 2
+        new_obj["w"].attrs["units"] = "(m/s)^2"
+        new_obj["w"].attrs["standard_name"] = "TKE"
 
-        self._obj["w"] = (
-            self._obj["u"] - self._obj["u"].mean(dim="t")
-        ) ** 2 + (self._obj["v"] - self._obj["v"].mean(dim="t")) ** 2
-        vel_units = self._obj.attrs["units"][-1]
-        if len(self._obj.attrs['units']) < 5:
-            self._obj.attrs["units"].append(f"({vel_units})^2")
-            self._obj.attrs["variables"].append("tke")
-        else:
-            self._obj.attrs["units"][-1]  = (f"({vel_units})^2")
-            self._obj.attrs["variables"][-1] = "tke"
-        return self._obj
+        return new_obj
 
     def fluct(self):
         """ returns fluctuations as a new dataset """
@@ -321,6 +275,10 @@ class PIVAccessor(object):
 
         new_obj = self._obj.copy()
         new_obj -= new_obj.mean(dim="t")
+
+        new_obj["u"].attrs["standard_name"] = "fluctation"
+        new_obj["v"].attrs["standard_name"] = "fluctation"
+
         return new_obj
 
     def reynolds_stress(self):
@@ -333,18 +291,28 @@ class PIVAccessor(object):
             )
 
         new_obj = self._obj.copy()
-        tmp = new_obj.mean(dim="t")
-        new_obj -= tmp # fluctuations
-        new_obj["w"] = new_obj["u"] * new_obj["v"] # new scalar
-        new_obj = new_obj.mean(dim="t") # reynolds stress is -\rho < u' v'>
+        new_obj -= new_obj.mean(dim="t")
 
-        return new_obj
+        new_obj["w"] = -1 * new_obj["u"] * new_obj["v"] # new scalar
+        self._obj["w"] = new_obj["w"].mean(dim="t") # reynolds stress is -\rho < u' v'>
+        self._obj["w"].attrs["standard_name"] = "Reynolds_stress"
+
+        return self._obj
+
+    def rms(self):
+        """ Root mean square """
+        self._obj = tke()
+        self._obj["w"] = np.sqrt(self._obj["w"])
+        self._obj["w"].attrs["standard_name"] = "rms"
+        self._obj["w"].attrs["units"] = "m/s"
 
     def vec2scal(self, property="curl"):
         """ creates a dataset of scalar values on the same
         dimensions and coordinates as the vector dataset
         Agruments:
             data : xarray.DataSet with u,v on t,x,y grid
+            property: str, one of the propertes from the list
+                'vorticity','kinetic_energy', 'tke', 'curl','strain'
         Returns:
             scalar_data : xarray.Dataset w on t,x,y grid
             'w' represents one of the following properties:
@@ -353,18 +321,15 @@ class PIVAccessor(object):
         """
         # replace few common names
         property = "vorticity" if property == "curl" else property
-        property = "tke" if property == "ken" else property
+        property = "kinetic_energy" if property == "ken" else property
+        property = "kinetic_energy" if property == "ke" else property
         property = "vorticity" if property == "vort" else property
+ 
+        method = getattr(self, str(property))
 
-        method_name = str(property)
-        method = getattr(self, method_name, lambda: "nothing")
+        self._obj = method()
 
-        # if len(self._obj.attrs["variables"]) < 5:  # only x,y,u,v
-        #     self._obj.attrs["variables"].append(property)
-        # else:
-        #     self._obj.attrs["variables"][-1] = property
-
-        return self._obj, method()
+        return self._obj
 
     def __mul__(self, scalar):
         """
@@ -387,7 +352,7 @@ class PIVAccessor(object):
         return self._obj
 
     def set_dt(self, dt):
-        self._obj.attrs["dt"] = dt
+        self._obj.attrs["delta_t"] = dt
         return self._obj
 
     def set_scale(self, scale=1.0):
@@ -431,25 +396,29 @@ class PIVAccessor(object):
     def dt(self):
         """ receives the dt from the set """
         if self._dt is None:
-            self._dt = self._obj.attrs["dt"]
+            self._dt = self._obj.attrs["delta_t"]
         return self._dt
 
     def quiver(self, **kwargs):
         """ graphics.quiver() as a property """
-        fig, ax = graphics.quiver(self._obj, **kwargs)
+        from pivpy.graphics import quiver
+        fig, ax = quiver(self._obj, **kwargs)
         return fig, ax
 
     def streamplot(self, **kwargs):
         """ graphics.quiver(streamlines=True) """
-        graphics.quiver(self._obj, streamlines=True, **kwargs)
+        from pivpy.graphics import quiver
+        quiver(self._obj, streamlines=True, **kwargs)
 
     def showf(self, **kwargs):
         """ method for graphics.showf """
-        graphics.showf(self._obj, **kwargs)
+        from pivpy.graphics import showf as gshowf
+        gshowf(self._obj, **kwargs)
 
     def showscal(self, **kwargs):
         """ method for graphics.showscal """
-        graphics.showscal(self._obj, **kwargs)
+        from pivpy.graphics import showscal
+        showscal(self._obj, **kwargs)
 
     # @property
     # def vel_units(self):
